@@ -7,7 +7,7 @@ class utility:
         print("constructor created")
 
     
-    def list_users(self,aws_secret_access_key,aws_access_key_id,aws_session_token,region_name,days):
+    def list_users(self,aws_secret_access_key,aws_access_key_id,aws_session_token,region_name,day):
         session = boto3.session.Session(
         aws_access_key_id=aws_secret_access_key,
         aws_secret_access_key=aws_access_key_id,
@@ -30,7 +30,7 @@ class utility:
                     try:
                         activity = user['PasswordLastUsed']
                         days = currentdate - activity
-                        if days.days >= days:
+                        if days.days >= day:
                             result["username"].append(user['UserName'])
                             result["Userid"].append(user['UserId'])
                             result["arn"].append(user['Arn'])
@@ -39,7 +39,7 @@ class utility:
                     except KeyError:
                         activity = user['CreateDate']
                         days = currentdate - activity
-                        if days.days >= days:
+                        if days.days >= day:
                             result["username"].append(user['UserName'])
                             result["Userid"].append(user['UserId'])
                             result["arn"].append(user['Arn'])
